@@ -28,7 +28,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // miraculix 0: vor Basic inttypes.h; Ausnahme initNerror.cc kleinkram.cc thuy.cc xport_import.cc zzz.cc
 // adoption 0: vor Basic kein inttypes.h
 
-#define RFU_VERSION 10
+#define RFU_VERSION 12
 
 
 #if defined RFU_LOCAL || defined RF_VERSION || defined MIRACULIX_VERSION || defined ADOPTION_VERSION || defined HAPLOBLOCKER_VERSION
@@ -413,7 +413,9 @@ typedef int64_t Long;
   #endif
 
 #else // NOT OBSOLETE
-  #define USE_FC_LEN_T
+  #if ! defined USE_FC_LEN_T
+    #define USE_FC_LEN_T
+  #endif
   #define ATAN2 std::atan2
   #define COSH std::cosh
   #define SINH std::sinh
@@ -421,6 +423,19 @@ typedef int64_t Long;
 #endif
 
 
+#if ! defined NA_LONG
+#define NA_LONG (-1L - (Long) 9223372036854775807)
+#endif
+
+
+
+
+#define FREE0(PT, WHICH) {			\
+  FREE(PT->WHICH); PT->n_##WHICH= 0;}		\
+  if (PT->WHICH != NULL) {			\
+    UNCONDFREE(PT->WHICH);			\
+    PT->n_##WHICH = 0;				\
+  } else assert(PT->n_##WHICH==0);						
 
 
 #endif
