@@ -39,11 +39,12 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // IMPORTANT: all names of general must have at least 3 letters !!!
 const char *basic[basicN] =
   { "printlevel","cPrintlevel", "seed", "cores",
-    "skipchecks", "asList", "verbose", "helpinfo", "efficient"
+    "skipchecks", "asList", "verbose", "helpinfo", "efficient",
+    "bigendian","warn_parallel"
   };
 
 const char *installNrun[installNrunN] =
-  { "kahanCorrection", "warn_unknown_option", "la_mode", "warn_parallel",
+  { "kahanCorrection", "warn_unknown_option", "la_mode", 
     "install","installPackages", "determineLAmode", "mem_is_aligned",
     "gpuDevices", "maxStreams"
   };
@@ -126,6 +127,8 @@ void setoptionsRFU(int i, int j, SEXP el, char name[LEN_OPTIONNAME],
       break;
     case 7: gp->helpinfo = LOGI; break;
     case 8 : gp->efficient = LOGI; break;
+    case 9: break; // bigendian; read only
+    case 10 : gp->warn_parallel = LOGI;  break;
     default: BUG;
     }}
     break;
@@ -162,8 +165,7 @@ void setoptionsRFU(int i, int j, SEXP el, char name[LEN_OPTIONNAME],
       }
     }
       break;     
-    case 3 : gp->warn_parallel = LOGI;  break;
-    case 4 : {
+    case 3 : {
       install_modes old =  gp->install;
       gp->install = (install_modes )
 	GetName(el, name, INSTALL_NAMES, INSTALL_LAST + 1, Iask);
@@ -174,17 +176,17 @@ void setoptionsRFU(int i, int j, SEXP el, char name[LEN_OPTIONNAME],
       }
     }
       break;
-    case 5 :
+    case 4 :
       // gp->installPackages != LOGI;  
       break;
-    case 6 : gp->determineLAmode = LOGI;  break;
-    case 7 :
+    case 5 : gp->determineLAmode = LOGI;  break;
+    case 6 :
       // gp->mem_is_aligned = LOGI;
       break;
-    case 8 :  Integer(el, name, gp->gpu_devices, MAX_GPU_DEVICES) ;
+    case 7 :  Integer(el, name, gp->gpu_devices, MAX_GPU_DEVICES) ;
       gp-> Ngpu_devices = MIN(length(el), MAX_GPU_DEVICES);
       break;
-     case 9 :
+     case 8 :
        gp->maxStreams = POS0INT;
       break;
    default: BUG;
@@ -236,15 +238,15 @@ void setoptionsRFU(int i, int j, SEXP el, char name[LEN_OPTIONNAME],
     case 13: if (!isList) {
       int len = length(el);
       if (len == 0) {
-	if (so->pivot_idx_n > 0) { FREE(so->pivot_idx); }
+	if (so->n_pivot_idx > 0) { FREE(so->pivot_idx); }
       } else {
-	if (so->pivot_idx_n != len) {
+	if (so->n_pivot_idx != len) {
 	  FREE(so->pivot_idx);
 	  so->pivot_idx = (int*) MALLOC(len * sizeof(int));
 	}
 	for (int L=0; L<len; L++) so->pivot_idx[L] = Integer(el, name, L);
       }
-      so->pivot_idx_n = len;     
+      so->n_pivot_idx = len;     
     }
       break; 
     case 14: so->pivot_relerror = POS0NUM; break;    
@@ -288,7 +290,9 @@ void getoptionsRFU(SEXP sublist, int i, utilsoption_type *options) {
     ADD(ScalarLogical(p->Rprintlevel >= PLverbose));
     ADD(ScalarLogical(p->helpinfo));    
     ADD(ScalarLogical(p->efficient));
-   }
+    ADD(ScalarLogical(p->bigendian));
+    ADD(ScalarLogical(p->warn_parallel));
+  }
     break;
  
   case 1 : {
@@ -296,7 +300,6 @@ void getoptionsRFU(SEXP sublist, int i, utilsoption_type *options) {
     ADD(ScalarLogical(p->kahanCorrection));   
     ADD(ScalarInteger(p->warn_unknown_option));    
     ADD(ScalarString(mkChar(LA_NAMES[p->la_usr])));
-    ADD(ScalarLogical(p->warn_parallel));
     ADD(ScalarString(mkChar(INSTALL_NAMES[p->install])));
     ADD(ScalarLogical(p->installPackages));
     ADD(ScalarLogical(p->determineLAmode));
@@ -328,7 +331,7 @@ void getoptionsRFU(SEXP sublist, int i, utilsoption_type *options) {
     ADD(ScalarInteger(p->max_svd)); 
     ADD(ScalarString(mkChar(PIVOT_NAMES[p->pivot_mode])));
     //if (true)
-    SET_VECTOR_ELT(sublist, k++, Int(p->pivot_idx, p->pivot_idx_n));
+    SET_VECTOR_ELT(sublist, k++, Int(p->pivot_idx, p->n_pivot_idx));
     //  else ADD(ScalarInteger(NA_INTEGER));
     //    ADD(ScalarLogical(p->tmp_delete));
      ADD(ScalarReal(p->pivot_relerror));    
@@ -355,7 +358,7 @@ void params_utilsoption(int local, int *params) {
     KEY_type *KT = KEYT();
     from = &(KT->global_utils);
   } 
-  params[PIVOT_IDX_N] = from->solve.pivot_idx_n;
+  params[PIVOT_IDX_N] = from->solve.n_pivot_idx;
 }
 
 void get_utilsoption(utilsoption_type *S, int local) {
@@ -365,15 +368,15 @@ void get_utilsoption(utilsoption_type *S, int local) {
     KEY_type *KT = KEYT();
     from = &(KT->global_utils);
   }
-  assert(from->solve.pivot_idx_n!=0 xor from->solve.pivot_idx == NULL);
-  assert(S->solve.pivot_idx_n!=0 xor S->solve.pivot_idx == NULL);
-  if (S->solve.pivot_idx_n != from->solve.pivot_idx_n) BUG;
+  assert(from->solve.n_pivot_idx!=0 xor from->solve.pivot_idx == NULL);
+  assert(S->solve.n_pivot_idx!=0 xor S->solve.pivot_idx == NULL);
+  if (S->solve.n_pivot_idx != from->solve.n_pivot_idx) BUG;
   int *save_idx = S->solve.pivot_idx;
   MEMCOPY(S, from, sizeof(utilsoption_type)); // OK
   S->solve.pivot_idx = save_idx;
-  if (S->solve.pivot_idx_n > 0) {
+  if (S->solve.n_pivot_idx > 0) {
     MEMCOPY(S->solve.pivot_idx, from->solve.pivot_idx, 
-	    sizeof(int) * S->solve.pivot_idx_n);
+	    sizeof(int) * S->solve.n_pivot_idx);
   }
 }
 
@@ -383,25 +386,25 @@ void push_utilsoption(utilsoption_type *S, int local) {
     KEY_type *KT = KEYT();
     to = &(KT->global_utils);
   } 
-  assert(to->solve.pivot_idx_n!=0 xor to->solve.pivot_idx == NULL);
-  assert(S->solve.pivot_idx_n!=0 xor S->solve.pivot_idx == NULL);
+  assert(to->solve.n_pivot_idx!=0 xor to->solve.pivot_idx == NULL);
+  assert(S->solve.n_pivot_idx!=0 xor S->solve.pivot_idx == NULL);
   int *save_idx = to->solve.pivot_idx;
-  if (to->solve.pivot_idx_n != S->solve.pivot_idx_n) {
+  if (to->solve.n_pivot_idx != S->solve.n_pivot_idx) {
     FREE(to->solve.pivot_idx);
-    to->solve.pivot_idx = (int*) MALLOC(S->solve.pivot_idx_n * sizeof(int));
+    to->solve.pivot_idx = (int*) MALLOC(S->solve.n_pivot_idx * sizeof(int));
     save_idx = to->solve.pivot_idx;
   }
   MEMCOPY(to, S, sizeof(utilsoption_type)); // OK
   to->solve.pivot_idx = save_idx;
-  if (S->solve.pivot_idx_n > 0) {
+  if (S->solve.n_pivot_idx > 0) {
     MEMCOPY(to->solve.pivot_idx, S->solve.pivot_idx,
-	    sizeof(int) * S->solve.pivot_idx_n);
+	    sizeof(int) * S->solve.n_pivot_idx);
   }
 }
 
 void del_utilsoption(utilsoption_type *S) {
   FREE(S->solve.pivot_idx);
-  S->solve.pivot_idx_n = 0;
+  S->solve.n_pivot_idx = 0;
 }
 
 
@@ -460,8 +463,8 @@ int own_chol_up_to(int size, int maxtime, int VARIABLE_IS_NOT_USED cores) {
     if (delta[0] > maxtime || delta[1] > maxtime ||
 	delta[0] >= FASTER * delta[1]){
       solve_DELETE0(&pt);
-      if (maxtime > 0 &&
-	  (delta[0] > 10 * maxtime || delta[1] > 10 * maxtime) ||
+      if ((maxtime > 0 &&
+	   (delta[0] > 10 * maxtime || delta[1] > 10 * maxtime)) ||
 	  delta[0] > 2 * delta[1] || delta[1] > 2 * delta[0]) {
 	// seems to be time consuming. So stop.
 	return (double) delta[0] < FASTER * (double) delta[1]
