@@ -5,7 +5,7 @@
 
  Collection of system specific auxiliary functions
 
- Copyright (C) 2001 -- 2017 Martin Schlather, 
+ Copyright (C) 2001 -- 2021 Martin Schlather
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -22,8 +22,10 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
-#ifdef WIN32
-// #define WIN32_LEAN_AND_MEAN
+
+#include "intrinsics.h"
+
+#if defined MSDOS_WINDOWS
 #define VC_EXTRALEAN
 #include <windows.h>
 #endif
@@ -35,44 +37,44 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #include <unistd.h>
 #include <Rinternals.h>
 #include "win_linux_aux.h"
-/*
-
-#include <unistd.h>
- 
-#include <R_ext/Lapack.h>
-#include <R_ext/Linpack.h>
-#include "RF.h"
-#include <Rdefines.h>
-*/
 
 
  
 void sleepMilli(int *milli) {
-#ifdef WIN32
-  Sleep((long) *milli);
+#if defined MSDOS_WINDOWS
+  Sleep((long) *milli); // along
 #else 
-  usleep((useconds_t) (1000 * (unsigned long) *milli));
+  usleep((useconds_t) (1000 * (unsigned long) *milli));// along
 #endif
 }
 
 void sleepMicro(int *micro) {
-#ifdef WIN32
-  Sleep((long) ((*micro + 500) / 1000));
+#if defined MSDOS_WINDOWS
+  Sleep((long) ((*micro + 500) / 1000));// along
 #else
   usleep((useconds_t) *micro);
 #endif
 }
 
 void pid(int *i)  {
-#ifdef WIN32 
+#if defined MSDOS_WINDOWS
   *i = _getpid();
 #else
   *i = getpid(); 
 #endif
 }
 
+int parentpid=0;
+bool
+  parallel() {
+    int mypid;
+    pid(&mypid);
+    return mypid != parentpid;
+  }
+
+
 void hostname(char **h, int *i){
-#ifdef WIN32
+#if defined MSDOS_WINDOWS
   *h[0]=0;
 #else
   gethostname(*h, *i);
@@ -80,3 +82,22 @@ void hostname(char **h, int *i){
 }  
 
 
+uint32_t cpuid_info(int Blatt, int Register) {
+#if defined MINGWCPUID
+   uint32_t s[4];						     
+   __cpuid(Blatt, s[0], s[1], s[2], s[3]);			    
+   return s[Register];
+#elif defined WINCPUID
+  uint32_t s[4];							
+  __cpuid((int *)s, (int) Blatt);
+  return s[Register];
+#elif defined LINUXCPUID
+  uint32_t s[4];							
+  asm volatile							
+    ("cpuid": "=a"(s[0]), "=b"(s[1]),"=c"(s[2]),			
+     "=d"(s[3]):"a"(Blatt),"c"(0));					
+  return s[Register]; 
+#else
+   return 0;
+#endif
+}
