@@ -36,7 +36,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 
 #ifdef __GNUC__
 // https://gcc.gnu.org/onlinedocs/gcc/Diagnostic-Pragmas.html
-//#pragma GCC diagnostic ignored "-Wcast-function-type"
+//// GCC diagnostic ignored "-Wcast-function-type"
 #endif
 
 static R_NativePrimitiveArgType 
@@ -185,9 +185,13 @@ void R_init_RandomFieldsUtils(DllInfo  *dll) {
 
 
   CALLABLE(ordering);
+  CALLABLE(orderingL);
   CALLABLE(orderingInt);
+  CALLABLE(orderingLong);
   CALLABLE(sorting);
+  CALLABLE(sortingL);
   CALLABLE(sortingInt);
+  CALLABLE(sortingLong);
   CALLABLE(scalarX);
   //  CALLABLE(scalarInt);
 
@@ -204,11 +208,11 @@ void R_init_RandomFieldsUtils(DllInfo  *dll) {
 #ifdef SCHLATHERS_MACHINE
 #ifdef __GNUC__ 
 // https://gcc.gnu.org/onlinedocs/gcc/Diagnostic-Pragmas.html
-//#pragma GCC diagnostic push
-//#pragma GCC diagnostic ignored "-Wcast-function-type"
+//// GCC diagnostic push
+//// GCC diagnostic ignored "-Wcast-function-type"
 #endif
 #endif
 void R_unload_RandomFieldsUtils(DllInfo *info) { }
 #ifdef __GNUC__ 
-//#pragma GCC diagnostic pop
+//// GCC diagnostic pop
 #endif
